# SPDX-License-Identifier: MIT

%global githubname QATzip
%global libqatzip_soversion 3

Summary:       Intel QuickAssist Technology (QAT) QATzip Library
Name:          qatzip
Version:       1.1.2
Release:       5%{?dist}
License:       BSD
URL:           https://github.com/intel/%{githubname}
Source0:       %{url}/archive/refs/tags/v%{version}.tar.gz
Patch0001: https://github.com/intel/QATzip/commit/49bcf697305ee71f954e2f08883fa18bcc689f5e.patch
Patch0002: https://github.com/intel/QATzip/commit/c116a7ef6c20f0871b9672d9ed930a252b40ba18.patch
Patch0003: https://github.com/intel/QATzip/commit/c43b17f1bc2b5c393b85259d9bd16635ed3f32c6.patch

BuildRequires: gcc zlib-devel qatlib-devel autoconf automake libtool make lz4-devel
ExclusiveArch: x86_64

%description
QATzip is a user space library which builds on top of the Intel QuickAssist Technology user space
library, to provide extended accelerated compression and decompression services by offloading the
actual compression and decompression request(s) to the Intel Chipset Series. QATzip produces data
using the standard gzip* format (RFC1952) with extended headers. The data can be decompressed with a
compliant gzip* implementation. QATzip is designed to take full advantage of the performance
provided by Intel QuickAssist Technology.

%package        libs
Summary:        Libraries for the qatzip package

%description    libs
This package contains libraries for applications to use the QATzip APIs.

%package        devel
Summary:        Development components for the libqatzip package
Requires:       %{name}-libs = %{version}-%{release}

%description    devel
This package contains headers and libraries required to build applications that use the QATzip APIs.

%prep
%autosetup -p1 -n %{githubname}-%{version}

%build
autoreconf -vif
./configure \
    --bindir=%{_bindir} \
    --libdir=%{_libdir} \
    --includedir=%{_includedir} \
    --mandir=%{_mandir} \
    --prefix=%{_prefix} \
    --enable-symbol

%make_build

%install
%make_install
rm %{buildroot}/%{_libdir}/libqatzip.a
rm %{buildroot}/%{_libdir}/libqatzip.la
rm -vf %{buildroot}%{_mandir}/*.pdf

%files
%license LICENSE*
%{_bindir}/qzip
%{_mandir}/man1/qzip.1*

%files libs
%license LICENSE*
%{_libdir}/libqatzip.so.%{libqatzip_soversion}*

%files devel
%doc docs/QATzip-man.pdf
%{_includedir}/qatzip.h
%{_libdir}/libqatzip.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Mon Dec 30 2024 Tracker Robot <trackbot@opencloudos.tech> - 1.1.2-5
- [Type] bugfix
- [DESC] Apply patches from rpm-tracker
- [Bug Fix] c43b17f1bc2b5c393b85259d9bd16635ed3f32c6.patch: QATAPP-31145: Fix null pointer dereference
- [Bug Fix] c116a7ef6c20f0871b9672d9ed930a252b40ba18.patch: QATAPP-31146: Fix potential double free
- [Performance] 49bcf697305ee71f954e2f08883fa18bcc689f5e.patch: QATAPP-29019: Improve sw fallback performance

* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.1.2-4
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.1.2-3
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.1.2-2
- Rebuilt for OpenCloudOS Stream 23.09

* Tue Jul 11 2023 Shuo Wang <abushwang@tencent.com> - 1.1.2-1
- update to 1.1.2

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.0.9-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.0.9-2
- Rebuilt for OpenCloudOS Stream 23

* Wed Mar 8 2023 Shuo Wang <abushwang@tencent.com> - 1.0.9-1
- initial build
